@@ -41,7 +41,11 @@ def lc_output(source, local_directory='', index=0, time=None, psf_lc=None, cal_p
     list of cadences of TESS FFI
     :return:
     """
-    objid = [int(s) for s in (source.gaia[index]['designation']).split() if s.isdigit()][0]
+    objid = [int(s) for s in (source.gaia[index]['DESIGNATION']).split() if s.isdigit()][0]
+    source_path = f'{local_directory}hlsp_tglc_tess_ffi_gaiaid-{objid}-s{source.sector:04d}-cam{source.camera}-ccd{source.ccd}_tess_v1_llc.fits'
+    source_exists = exists(source_path)
+    if source_exists and os.path.getsize(source_path) > 0:
+        return
     if np.isnan(source.gaia[index]['phot_bp_mean_mag']) or ma.is_masked(source.gaia[index]['phot_bp_mean_mag']):
         gaia_bp = 'NaN'
     else:
@@ -91,7 +95,7 @@ def lc_output(source, local_directory='', index=0, time=None, psf_lc=None, cal_p
         fits.Card('TELESCOP', 'TESS', 'telescope'),
         fits.Card('INSTRUME', 'TESS Photometer', 'detector type'),
         fits.Card('FILTER', 'TESS', 'the filter used for the observations'),
-        fits.Card('OBJECT', source.gaia[index]['designation'], 'string version of Gaia DR3 ID'),
+        fits.Card('OBJECT', source.gaia[index]['DESIGNATION'], 'string version of Gaia DR3 ID'),
         fits.Card('GAIADR3', objid, 'integer version of Gaia DR3 ID'),
         fits.Card('TICID', ticid, 'TESS Input Catalog ID'),
         fits.Card('SECTOR', source.sector, 'observation sector'),
@@ -149,7 +153,7 @@ def lc_output(source, local_directory='', index=0, time=None, psf_lc=None, cal_p
     table_hdu.header.append(('TELESCOP', 'TESS', 'telescope'), end=True)
     table_hdu.header.append(('INSTRUME', 'TESS Photometer', 'detector type'), end=True)
     table_hdu.header.append(('FILTER', 'TESS', 'the filter used for the observations'), end=True)
-    table_hdu.header.append(('OBJECT', source.gaia[index]['designation'], 'string version of Gaia DR3 ID'),
+    table_hdu.header.append(('OBJECT', source.gaia[index]['DESIGNATION'], 'string version of Gaia DR3 ID'),
                             end=True)
     table_hdu.header.append(('GAIADR3', objid, 'integer version of GaiaDR3 designation'), end=True)
     table_hdu.header.append(('RADESYS', 'ICRS', 'reference frame of celestial coordinates'), end=True)
@@ -234,8 +238,7 @@ def epsf(source, psf_size=11, factor=2, local_directory='', target=None, cut_x=0
     else:
         e_psf = np.zeros((len(source.time), over_size ** 2 + bg_dof))
         for i in trange(len(source.time), desc='Fitting ePSF', disable=no_progress_bar):
-            fit = fit_psf(A, source, over_size, power=power, time=i)
-            e_psf[i] = fit
+            e_psf[i] = fit_psf(A, source, over_size, power=power, time=i)
         if np.isnan(e_psf).any():
             warnings.warn(
                 f"TESS FFI cut includes Nan values. Please shift the center of the cutout to remove Nan near edge. Target: {target}")
@@ -269,7 +272,7 @@ def epsf(source, psf_size=11, factor=2, local_directory='', target=None, cut_x=0
     start = 0
     end = num_stars
     if name is not None:
-        start = int(np.where(source.gaia['designation'] == name)[0][0])
+        start = int(np.where(source.gaia['DESIGNATION'] == name)[0][0])
         end = start + 1
     for i in trange(start, end, desc='Fitting lc', disable=no_progress_bar):
         if x_left <= x_round[i] < source.size - x_right and y_left <= y_round[i] < source.size - y_right:
@@ -296,6 +299,16 @@ def epsf(source, psf_size=11, factor=2, local_directory='', target=None, cut_x=0
             aper_lc = np.sum(
                 aperture[:, max(0, star_y - 1):min(5, star_y + 2), max(0, star_x - 1):min(5, star_x + 2)],
                 axis=(1, 2))
+            if source.sector < 27:  # primary
+                exposure_time = 1800
+            elif source.sector < 56:  # first extended
+                exposure_time = 600
+            else:  # second extended
+                exposure_time = 200
+            saturated_arg_aper = np.where(aper_lc > 1e5 * 9 * 2e5 / exposure_time)  # saturation is 2e5 e-
+            aper_lc[saturated_arg_aper] = np.nan
+            saturated_arg_psf = np.where(psf_lc > 1e5 * 9 * 2e5 / exposure_time)
+            psf_lc[saturated_arg_psf] = np.nan
             local_bg, aper_lc, psf_lc, cal_aper_lc, cal_psf_lc = bg_mod(source, q=index, portion=portion,
                                                                         psf_lc=psf_lc,
                                                                         aper_lc=aper_lc,
